Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(115)

Unified Diff: net/http/mock_http_cache.h

Issue 2671793002: Correct handling of ERR_CACHE_LOCK_TIMEOUT for read only transactions. (Closed)
Patch Set: Feedback addressed. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/http/http_cache_unittest.cc ('k') | net/http/mock_http_cache.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/http/mock_http_cache.h
diff --git a/net/http/mock_http_cache.h b/net/http/mock_http_cache.h
index 7cf03db4051170a08b6d579624f2669cdd623f73..38e932d3985164c9c0ab6677775c25b2504c7e08 100644
--- a/net/http/mock_http_cache.h
+++ b/net/http/mock_http_cache.h
@@ -194,8 +194,8 @@ class MockHttpCache {
// Wrapper around http_cache()->CreateTransaction(DEFAULT_PRIORITY...)
int CreateTransaction(std::unique_ptr<HttpTransaction>* trans);
- // Wrapper to bypass the cache lock for new transactions.
- void BypassCacheLock();
+ // Wrapper to simulate cache lock timeout for new transactions.
+ void SimulateCacheLockTimeout();
// Wrapper to fail request conditionalization for new transactions.
void FailConditionalizations();
« no previous file with comments | « net/http/http_cache_unittest.cc ('k') | net/http/mock_http_cache.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698